@@ -8,7 +8,7 @@ test_that("design library dependency works",{
   design_2 <- DesignLibrary::multi_arm_designer(N = 500, m_arms = 3, outcome_means = c(0, 0, 1))
   dx <- diagnose_design(design_1, design_2, sims = 3, bootstrap_sims = FALSE)
   
-  expect_true(all(c("design_1", "design_2") %in% dx$diagnosands_df$design_label))
+  expect_true(all(c("design_1", "design_2") %in% dx$diagnosands_df$design))
   
 })
 
