@@ -1,7 +1,7 @@
 context("environment problems")
 
 test_that("send inquiry to estimator works", {
-  my_population <- declare_population(N = 50, noise = rnorm(N))
+  my_population <- declare_model(N = 50, noise = rnorm(N))
 
   my_potential_outcomes <-
     declare_potential_outcomes(
@@ -15,19 +15,19 @@ test_that("send inquiry to estimator works", {
 
   pate_estimator <- declare_estimator(Y ~ Z, inquiry = pate, label = "test")
 
-  declare_reveal <- declare_reveal()
+  my_measurement <- declare_measurement(Y = reveal_outcomes(Y ~ Z)) 
 
   my_design <- my_population +
     my_potential_outcomes +
     pate +
     my_assignment +
-    declare_reveal +
+    my_measurement +
     pate_estimator
 
   rm(list = ls()[-which(ls() %in% "my_design")])
   diag <- diagnose_design(my_design, sims = 2, bootstrap_sims = 3)
 
-  expect_equal(names(diag), c("simulations_df", "diagnosands_df", "diagnosand_names", "group_by_set", "parameters_df", "bootstrap_replicates", "bootstrap_sims"))
+  expect_equal(names(diag), c("simulations_df", "diagnosands_df", "diagnosand_names", "group_by_set", "parameters_df", "bootstrap_replicates", "bootstrap_sims", "duration"))
   expect_equal(nrow(diag$simulations_df), 2)
   expect_equal(nrow(diag$diagnosands_df), 1)
   expect_equal(nrow(diag$bootstrap_replicates), 3)
